@@ -32,6 +32,9 @@ class Puppet::Provider::Cinder < Puppet::Provider::Openstack
     @credentials.password = cinder_credentials['password']
     @credentials.project_name = cinder_credentials['project_name']
     @credentials.auth_url = auth_endpoint
+    if cinder_credentials['region_name']
+      @credentials.region_name = cinder_credentials['region_name']
+    end
     if @credentials.version == '3'
       @credentials.user_domain_name = cinder_credentials['user_domain_name']
       @credentials.project_domain_name = cinder_credentials['project_domain_name']
@@ -49,7 +52,7 @@ class Puppet::Provider::Cinder < Puppet::Provider::Openstack
   end
 
   def self.get_cinder_credentials
-    auth_keys = ['auth_uri', 'project_name', 'username',
+    auth_keys = ['www_authenticate_uri', 'project_name', 'username',
                  'password']
     conf = cinder_conf
     if conf and conf['keystone_authtoken'] and
@@ -66,6 +69,9 @@ class Puppet::Provider::Cinder < Puppet::Provider::Openstack
       else
         creds['user_domain_name'] = 'Default'
       end
+      if conf['DEFAULT'] and conf['DEFAULT']['os_region_name']
+        creds['region_name'] = conf['DEFAULT']['os_region_name']
+      end
       return creds
     else
       raise(Puppet::Error, "File: #{conf_filename} does not contain all " +
@@ -76,7 +82,7 @@ class Puppet::Provider::Cinder < Puppet::Provider::Openstack
 
   def self.get_auth_endpoint
     q = cinder_credentials
-    "#{q['auth_uri']}"
+    "#{q['www_authenticate_uri']}"
   end
 
   def self.auth_endpoint
