@@ -3,8 +3,14 @@ require 'spec_helper'
 describe 'cinder::api' do
 
   shared_examples_for 'cinder api' do
+    let :pre_condition do
+      "class { '::cinder::keystone::authtoken':
+         password => 'foo',
+      }"
+    end
+
     let :req_params do
-      {:keystone_password => 'foo'}
+      {}
     end
 
     describe 'with only required params' do
@@ -14,8 +20,8 @@ describe 'cinder::api' do
 
       it { is_expected.to contain_service('cinder-api').with(
         'hasstatus' => true,
-        'ensure' => 'running',
-        'tag' => 'cinder-service',
+        'ensure'    => 'running',
+        'tag'       => 'cinder-service',
       )}
 
       it 'should configure cinder api correctly' do
@@ -28,9 +34,6 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with(
          :value => 'compute:Compute Service:publicURL'
         )
-        is_expected.to contain_cinder_config('DEFAULT/nova_catalog_admin_info').with(
-         :value => 'compute:Compute Service:adminURL'
-        )
         is_expected.to contain_cinder_config('DEFAULT/default_volume_type').with(
          :value => '<SERVICE DEFAULT>'
         )
@@ -46,62 +49,33 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/os_region_name').with(
          :value => '<SERVICE DEFAULT>'
         )
-        is_expected.to contain_cinder_config('keystone_authtoken/auth_uri').with(
-         :value => 'http://localhost:5000'
+        is_expected.to contain_cinder_config('DEFAULT/auth_strategy').with(
+         :value => 'keystone'
         )
-        is_expected.to contain_cinder_config('keystone_authtoken/auth_url').with(
-         :value => 'http://localhost:35357'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/project_name').with(
-         :value => 'services'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/username').with(
-         :value => 'cinder'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/password').with(
-         :value => 'foo'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_password').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('key_manager/api_class').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('key_manager/backend').with_value('cinder.keymgr.conf_key_mgr.ConfKeyManager')
         is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen_port').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__middleware('cinder_config').with(
+          :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+        )
       end
     end
 
     describe 'with a custom nova_catalog params' do
       let :params do
         req_params.merge({
-          'nova_catalog_admin_info' => 'compute:nova:adminURL',
-          'nova_catalog_info' => 'compute:nova:publicURL',
+          'nova_catalog_info'       => 'compute:nova:publicURL',
         })
       end
-      it { is_expected.to contain_cinder_config('DEFAULT/nova_catalog_admin_info').with_value('compute:nova:adminURL') }
       it { is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with_value('compute:nova:publicURL') }
     end
 
-    describe 'without deprecated keystone_authtoken parameters' do
-      let :params do
-        req_params.merge({
-          'keystone_user'   => 'dummy',
-          'keystone_tenant' => 'mytenant',
-          'identity_uri'    => 'https://127.0.0.1:35357/deprecated',
-          'auth_uri'        => 'https://127.0.0.1:5000/deprecated',
-        })
-      end
-
-      it { is_expected.to contain_cinder_config('keystone_authtoken/auth_url').with_value('https://127.0.0.1:35357/deprecated') }
-      it { is_expected.to contain_cinder_config('keystone_authtoken/username').with_value('dummy') }
-      it { is_expected.to contain_cinder_config('keystone_authtoken/project_name').with_value('mytenant') }
-      it { is_expected.to contain_cinder_config('keystone_authtoken/auth_uri').with_value('https://127.0.0.1:5000/deprecated') }
-    end
-
     describe 'with a custom region for nova' do
       let :params do
         req_params.merge({'os_region_name' => 'MyRegion'})
@@ -218,9 +192,8 @@ describe 'cinder::api' do
     describe 'with sync_db set to false' do
       let :params do
         {
-          :keystone_password => 'dummy',
-          :enabled           => true,
-          :sync_db           => false,
+          :enabled => true,
+          :sync_db => false,
         }
       end
       it { is_expected.not_to contain_class('cinder::db::sync') }
@@ -276,47 +249,20 @@ describe 'cinder::api' do
           :validate => true,
         })
       end
-      it { is_expected.to contain_exec('execute cinder-api validation').with(
-        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider    => 'shell',
-        :tries       => '10',
-        :try_sleep   => '2',
-        :command     => 'cinder --os-auth-url http://localhost:5000 --os-project-name services --os-username cinder --os-password foo list',
-      )}
-
-      it { is_expected.to contain_anchor('create cinder-api anchor').with(
-        :require => 'Exec[execute cinder-api validation]',
+      it { is_expected.to contain_openstacklib__service_validation('cinder-api').with(
+        :command   => 'cinder --os-auth-url http://localhost:5000 --os-project-name services --os-username cinder --os-password foo list',
+        :subscribe => 'Service[cinder-api]',
       )}
     end
 
-    describe 'while validating the service with custom command' do
+    describe 'with a custom auth_strategy' do
       let :params do
-        req_params.merge({
-          :validate            => true,
-          :validation_options  => { 'cinder-api' => { 'command' => 'my-script' } }
-        })
+        req_params.merge({'auth_strategy' => 'noauth'})
       end
-      it { is_expected.to contain_exec('execute cinder-api validation').with(
-        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider    => 'shell',
-        :tries       => '10',
-        :try_sleep   => '2',
-        :command     => 'my-script',
-      )}
-
-      it { is_expected.to contain_anchor('create cinder-api anchor').with(
-        :require => 'Exec[execute cinder-api validation]',
-      )}
-    end
-
-    describe "with deprecated memcached servers for keystone authtoken" do
-      let :params do
-        req_params.merge({
-          :memcached_servers => '1.1.1.1:11211',
-        })
-      end
-      it 'configures memcached servers' do
-        is_expected.to contain_cinder_config('keystone_authtoken/memcached_servers').with_value('1.1.1.1:11211')
+      it 'should configure the auth_strategy to noauth' do
+        is_expected.to contain_cinder_config('DEFAULT/auth_strategy').with(
+          :value => 'noauth'
+        )
       end
     end
 
@@ -332,31 +278,37 @@ describe 'cinder::api' do
     end
     describe 'when running cinder-api in wsgi' do
       let :params do
-        req_params.merge!({ :service_name   => 'httpd' })
+        req_params.merge!({ :service_name => 'httpd' })
       end
 
       let :pre_condition do
         "include ::apache
-         class { 'cinder': rabbit_password => 'secret' }"
+         class { 'cinder': }
+         class { '::cinder::keystone::authtoken':
+           password => 'foo',
+         }"
       end
 
       it 'configures cinder-api service with Apache' do
         is_expected.to contain_service('cinder-api').with(
-          :ensure     => 'stopped',
-          :enable     => false,
-          :tag        => ['cinder-service'],
+          :ensure => 'stopped',
+          :enable => false,
+          :tag    => ['cinder-service'],
         )
       end
     end
 
     describe 'when service_name is not valid' do
       let :params do
-        req_params.merge!({ :service_name   => 'foobar' })
+        req_params.merge!({ :service_name => 'foobar' })
       end
 
       let :pre_condition do
         "include ::apache
-         class { 'cinder': rabbit_password => 'secret' }"
+         class { 'cinder': }
+         class { '::cinder::keystone::authtoken':
+           password => 'foo',
+         }"
       end
 
       it_raises 'a Puppet::Error', /Invalid service_name/
@@ -365,10 +317,10 @@ describe 'cinder::api' do
     describe 'with SSL socket options set' do
       let :params do
         req_params.merge!({
-          :use_ssl         => true,
-          :cert_file       => '/path/to/cert',
-          :ca_file         => '/path/to/ca',
-          :key_file        => '/path/to/key',
+          :use_ssl   => true,
+          :cert_file => '/path/to/cert',
+          :ca_file   => '/path/to/ca',
+          :key_file  => '/path/to/key',
         })
       end
 
@@ -380,9 +332,9 @@ describe 'cinder::api' do
     describe 'with SSL socket options set wrongly configured' do
       let :params do
         req_params.merge!({
-          :use_ssl         => true,
-          :ca_file         => '/path/to/ca',
-          :key_file        => '/path/to/key',
+          :use_ssl  => true,
+          :ca_file  => '/path/to/ca',
+          :key_file => '/path/to/key',
         })
       end
 
@@ -392,18 +344,29 @@ describe 'cinder::api' do
     describe 'with barbican parameters' do
       let :params do
         req_params.merge!({
-          :keymgr_api_class           => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
+          :keymgr_backend             => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           :keymgr_encryption_api_url  => 'https://localhost:9311/v1',
           :keymgr_encryption_auth_url => 'https://localhost:5000/v3',
         })
       end
       it 'should set keymgr parameters' do
-        is_expected.to contain_cinder_config('key_manager/api_class').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
+        is_expected.to contain_cinder_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
         is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('https://localhost:9311/v1')
         is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('https://localhost:5000/v3')
       end
     end
 
+    describe 'with barbican deprecated parameters' do
+      let :params do
+        req_params.merge!({
+          :keymgr_api_class           => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
+        })
+      end
+      it 'should set keymgr parameter' do
+        is_expected.to contain_cinder_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
+      end
+    end
+
   end
 
   on_supported_os({
@@ -412,7 +375,7 @@ describe 'cinder::api' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
+          :os_workers     => 8,
           :fqdn           => 'some.host.tld',
           :concat_basedir => '/var/lib/puppet/concat',
         }))
