@@ -25,13 +25,13 @@ describe 'cinder::backup::swift' do
   let :default_params do
     { :backup_swift_url             => '<SERVICE DEFAULT>',
       :backup_swift_auth_url        => '<SERVICE DEFAULT>',
-      :backup_swift_container       => 'volumes_backup',
+      :backup_swift_container       => 'volumebackups',
       :backup_swift_object_size     => '<SERVICE DEFAULT>',
       :backup_swift_retry_attempts  => '<SERVICE DEFAULT>',
       :backup_swift_retry_backoff   => '<SERVICE DEFAULT>',
-      :backup_swift_user_domain     => '<SERVICE_DEFAULT>',
-      :backup_swift_project_domain  => '<SERVICE_DEFAULT>',
-      :backup_swift_project         => '<SERVICE_DEFAULT>',
+      :backup_swift_user_domain     => '<SERVICE DEFAULT>',
+      :backup_swift_project_domain  => '<SERVICE DEFAULT>',
+      :backup_swift_project         => '<SERVICE DEFAULT>',
       :backup_compression_algorithm => '<SERVICE DEFAULT>' }
   end
 
@@ -52,16 +52,16 @@ describe 'cinder::backup::swift' do
       is_expected.to contain_cinder_config('DEFAULT/backup_swift_object_size').with_value(p[:backup_swift_object_size])
       is_expected.to contain_cinder_config('DEFAULT/backup_swift_retry_attempts').with_value(p[:backup_swift_retry_attempts])
       is_expected.to contain_cinder_config('DEFAULT/backup_swift_retry_backoff').with_value(p[:backup_swift_retry_backoff])
-      is_expected.to contain_cinder_config('DEFAULT/backup_swift_user_domain').with_value(p[:backup_compression_algorithm])
-      is_expected.to contain_cinder_config('DEFAULT/backup_swift_project_domain').with_value(p[:backup_compression_algorithm])
-      is_expected.to contain_cinder_config('DEFAULT/backup_swift_project').with_value(p[:backup_compression_algorithm])
+      is_expected.to contain_cinder_config('DEFAULT/backup_swift_user_domain').with_value(p[:backup_swift_user_domain])
+      is_expected.to contain_cinder_config('DEFAULT/backup_swift_project_domain').with_value(p[:backup_swift_project_domain])
+      is_expected.to contain_cinder_config('DEFAULT/backup_swift_project').with_value(p[:backup_swift_project])
       is_expected.to contain_cinder_config('DEFAULT/backup_compression_algorithm').with_value(p[:backup_compression_algorithm])
     end
 
     context 'when overriding default parameters' do
       before :each do
         params.merge!(:backup_swift_url => 'https://controller2:8080/v1/AUTH_')
-        params.merge!(:backup_swift_auth_url => 'https://controller2:35357')
+        params.merge!(:backup_swift_auth_url => 'https://controller2:5000')
         params.merge!(:backup_swift_container => 'toto')
         params.merge!(:backup_swift_object_size => '123')
         params.merge!(:backup_swift_retry_attempts => '99')
@@ -85,7 +85,7 @@ describe 'cinder::backup::swift' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({:processorcount => 8}))
+        facts.merge(OSDefaults.get_facts({:os_workers => 8}))
       end
 
       it_configures 'cinder backup with swift'
