@@ -10,7 +10,14 @@ describe 'cinder::db::sync' do
         :user        => 'cinder',
         :path        => '/usr/bin',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[cinder::install::end]',
+                         'Anchor[cinder::config::end]',
+                         'Anchor[cinder::dbsync::begin]'],
+        :notify      => 'Anchor[cinder::dbsync::end]',
+        :tag         => 'openstack-db',
       )
     end
 
@@ -27,7 +34,14 @@ describe 'cinder::db::sync' do
           :user        => 'cinder',
           :path        => '/usr/bin',
           :refreshonly => 'true',
-          :logoutput   => 'on_failure'
+          :try_sleep   => 5,
+          :tries       => 10,
+          :logoutput   => 'on_failure',
+          :subscribe   => ['Anchor[cinder::install::end]',
+                         'Anchor[cinder::config::end]',
+                         'Anchor[cinder::dbsync::begin]'],
+          :notify      => 'Anchor[cinder::dbsync::end]',
+          :tag         => 'openstack-db',
         )
       }
     end
@@ -40,7 +54,7 @@ describe 'cinder::db::sync' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
+          :os_workers     => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
