@@ -71,7 +71,7 @@ describe 'cinder::glance' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({:processorcount => 8}))
+        facts.merge(OSDefaults.get_facts({:os_workers => 8}))
       end
 
       it_configures 'cinder with glance'
