@@ -10,6 +10,7 @@ describe 'cinder::backend::eqlx' do
       :san_ip               => '192.168.100.10',
       :san_login            => 'grpadmin',
       :san_password         => '12345',
+      :san_private_key      => '',
       :volume_backend_name  => 'Dell_EQLX',
       :san_thin_provision   => '<SERVICE DEFAULT>',
       :eqlx_group_name      => '<SERVICE DEFAULT>',
@@ -27,7 +28,7 @@ describe 'cinder::backend::eqlx' do
       is_expected.to contain_cinder__backend__eqlx(config_group_name)
       is_expected.to contain_cinder_config(
         "#{config_group_name}/volume_driver").with_value(
-        'cinder.volume.drivers.eqlx.DellEQLSanISCSIDriver')
+        'cinder.volume.drivers.dell_emc.ps.PSSeriesISCSIDriver')
       params.each_pair do |config,value|
         is_expected.to contain_cinder_config(
           "#{config_group_name}/#{config}").with_value(value)
