@@ -6,15 +6,19 @@ describe 'cinder::backend::nfs' do
 
   let :params do
     {
-      :nfs_servers          => ['10.10.10.10:/shares', '10.10.10.10:/shares2'],
-      :nfs_mount_attempts   => '4',
-      :nfs_mount_options    => 'vers=3',
-      :nfs_shares_config    => '/etc/cinder/other_shares.conf',
-      :nfs_disk_util        => 'du',
-      :nfs_sparsed_volumes  => true,
-      :nfs_mount_point_base => '/cinder_mount_point',
-      :nfs_used_ratio       => '0.7',
-      :nfs_oversub_ratio    => '0.9'
+      :nfs_servers                 => ['10.10.10.10:/shares', '10.10.10.10:/shares2'],
+      :nfs_mount_attempts          => '4',
+      :nfs_mount_options           => 'vers=3',
+      :nfs_shares_config           => '/etc/cinder/other_shares.conf',
+      :nfs_disk_util               => 'du',
+      :nfs_sparsed_volumes         => true,
+      :nfs_mount_point_base        => '/cinder_mount_point',
+      :nfs_used_ratio              => '0.7',
+      :nfs_oversub_ratio           => '0.9',
+      :nas_secure_file_operations  => 'auto',
+      :nas_secure_file_permissions => 'false',
+      :nfs_snapshot_support        => 'true',
+      :nfs_qcow2_volumes           => 'true',
     }
   end
 
@@ -41,6 +45,14 @@ describe 'cinder::backend::nfs' do
         '0.7')
       is_expected.to contain_cinder_config('hippo/nfs_oversub_ratio').with_value(
         '0.9')
+      is_expected.to contain_cinder_config('hippo/nas_secure_file_operations').with_value(
+        'auto')
+      is_expected.to contain_cinder_config('hippo/nas_secure_file_permissions').with_value(
+        'false')
+      is_expected.to contain_cinder_config('hippo/nfs_snapshot_support').with_value(
+        'true')
+      is_expected.to contain_cinder_config('hippo/nfs_qcow2_volumes').with_value(
+        'true')
       is_expected.to contain_file('/etc/cinder/other_shares.conf').with(
         :content => "10.10.10.10:/shares\n10.10.10.10:/shares2",
         :require => 'Anchor[cinder::install::end]',
